Tushare股票特色数据将陆续上线，第一批包括卖方盈利预测、股票每日筹码和成本数据等。

1、券商（卖方）盈利预测数据

  数据来自于券商发布的研究报告，通过结构化，提取针对个股的盈利预测和评级数据。数据从2010年开始，提供超过10年的盈利预测数据，每天20点更新。主要的盈利预测数据主要来自报告的核心部分，如下图：

部分券商给出了评级，比如强烈推荐买入，增持等，以及未来一年或半年内最高目标价和最低目标价信息。

2、股票每日筹码成本和胜率

  筹码数据分析投资者持仓成本的关键指标数据，本接口提供每个股票每天的平均成本以及胜率数据。在各大行情软件上，我们都可以看到筹码展示，但绝大多数数据公司都不直接提供筹码数据API或者数据库服务，Tushare根据多年经验，自行设计开发了筹码数据供用户使用，因每家公司算法不同，甚至用于计算的基础数据也不同，因此数据会有一些差异，这属于正常情况。

Tushare的每日筹码平均成本和胜率数据，主要包括了：该股历史最高价、最低价、各分位持仓成本价格、加权平均价和胜率。

3、股票每日筹码分布

  股票的每日筹码筹码分布，是每个股票每天的持仓价位及占比，能详细看出当前投资者的持仓成本情况。数据在各大行情软件上呈现出的是一个堆积的波浪图形状。由于目前市场直接提供该类数据的供应商非常少，对于量化分析或者筹码数据融入量化策略中寻求Alpha则非常困难，我们通过直接提供API方式为用户方便获取筹码数据开发另类策略提供了可能。

每日筹码分布数据，包括了成本价附近上下各50档成本的分布，一定程度体现了市场的持仓成本分布情况。注：该数据只作为参考，不具有绝对真实性。

4、券商金股数据

 券商研究所一般会在每个月末发布下个月十大金股，代表了该研究所和各团队对下个月市场热点的观点，通过收集市场金股数据，可以形成一致预期效果，对投资者有一定参考作用，尤其从组合的角度作为选择的依据之一。建议投资者跟踪参考，积2000积分可以调取。